# Contributor Covenant Code of Conduct

## Our Pledge

We as members, contributors, and leaders pledge to make participation in our
community a harassment-free experience for everyone, regardless of age, body
size, visible or invisible disability, ethnicity, gender identity and expression,
level of experience, education, socio-economic status, nationality, personal
appearance, race, religion, or orientation.

We pledge to act and interact in ways that contribute to an open, welcoming,
diverse, inclusive, and healthy community.

## Our Standards

Examples of behavior that contributes to a positive environment:

* Demonstrating empathy and kindness toward other people
* Being respectful of differing opinions, viewpoints, and experiences
* Giving and gracefully accepting constructive feedback
* Accepting responsibility and apologizing to those affected by our mistakes
* Focusing on what is best for the community

Examples of unacceptable behavior:

* Trolling, insulting or derogatory comments, and personal attacks
* Public or private harassment
* Publishing others' private information without permission
* Other conduct which could reasonably be considered inappropriate

## Enforcement Responsibilities

Community leaders are responsible for clarifying and enforcing our standards of
acceptable behavior and will take appropriate action in response to any behavior
that they deem inappropriate, threatening, offensive, or harmful.

## Scope

This Code of Conduct applies within all community spaces, and also applies when
an individual is officially representing the community in public spaces.

## Enforcement

Instances of abusive, harassing, or otherwise unacceptable behavior may be
reported to the project maintainers.

All complaints will be reviewed and investigated promptly and fairly.

## Enforcement Guidelines

Community leaders will follow these guidelines in determining consequences:

### 1. Correction

**Community Impact**: Use of inappropriate language or other unprofessional behavior.

**Consequence**: A private, written warning providing clarity around the violation.

### 2. Warning

**Community Impact**: A violation through a single incident or series of actions.

**Consequence**: A warning with consequences for continued behavior.

### 3. Temporary Ban

**Community Impact**: A serious violation of community standards.

**Consequence**: A temporary ban from community interaction.

### 4. Permanent Ban

**Community Impact**: Demonstrating a pattern of violation of community standards.

**Consequence**: A permanent ban from community interaction.

## Attribution

This Code of Conduct is adapted from the [Contributor Covenant][homepage],
version 2.1, available at
[https://www.contributor-covenant.org/version/2/1/code_of_conduct.html][v2.1].

[homepage]: https://www.contributor-covenant.org
[v2.1]: https://www.contributor-covenant.org/version/2/1/code_of_conduct.html

---

## Additional Community Guidelines

### Semantic Data Charter Values

In addition to the Contributor Covenant, we uphold these values:

#### Standards Excellence
We strive for excellence in data standards and semantic modeling. Constructive
technical debate is encouraged but must remain respectful and evidence-based.

#### Inclusive Innovation
We welcome contributors from diverse backgrounds including governance,
compliance, data architecture, and software development.

#### Collaborative Spirit
The SDC ecosystem spans multiple projects and organizations. We encourage
collaboration and respectful engagement with the broader standards community.

#### Educational Focus
We recognize that governance standards and semantic data modeling can be complex.
Patience and willingness to help others learn are essential community values.

---

*This Code of Conduct applies to all SDC_Agents community spaces.*
